[−][src]Enum gdnative_common::DynamicFontDataHinting
Variants
NoneLightNormalTrait Implementations
impl Eq for DynamicFontDataHinting[src]
impl Eq for DynamicFontDataHintingimpl Copy for DynamicFontDataHinting[src]
impl Copy for DynamicFontDataHintingimpl PartialEq<DynamicFontDataHinting> for DynamicFontDataHinting[src]
impl PartialEq<DynamicFontDataHinting> for DynamicFontDataHintingfn eq(&self, other: &DynamicFontDataHinting) -> bool | [src] |
| 1.0.0 [src] |
This method tests for !=.
impl Clone for DynamicFontDataHinting[src]
impl Clone for DynamicFontDataHintingfn clone(&self) -> DynamicFontDataHinting | [src] |
fn clone_from(&mut self, source: &Self) | 1.0.0 [src] |
Performs copy-assignment from source. Read more
impl Debug for DynamicFontDataHinting[src]
impl Debug for DynamicFontDataHintingimpl Hash for DynamicFontDataHinting[src]
impl Hash for DynamicFontDataHintingAuto Trait Implementations
impl Send for DynamicFontDataHinting
impl Send for DynamicFontDataHintingimpl Sync for DynamicFontDataHinting
impl Sync for DynamicFontDataHintingBlanket Implementations
impl<T> From for T[src]
impl<T> From for Timpl<T, U> Into for T where
U: From<T>, [src]
impl<T, U> Into for T where
U: From<T>, impl<T> ToOwned for T where
T: Clone, [src]
impl<T> ToOwned for T where
T: Clone, impl<T, U> TryFrom for T where
T: From<U>, [src]
impl<T, U> TryFrom for T where
T: From<U>, type Error = !
🔬 This is a nightly-only experimental API. (
try_from)The type returned in the event of a conversion error.
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error> | [src] |
impl<T> Borrow for T where
T: ?Sized, [src]
impl<T> Borrow for T where
T: ?Sized, impl<T> BorrowMut for T where
T: ?Sized, [src]
impl<T> BorrowMut for T where
T: ?Sized, fn borrow_mut(&mut self) -> &mut T | [src] |
impl<T, U> TryInto for T where
U: TryFrom<T>, [src]
impl<T, U> TryInto for T where
U: TryFrom<T>, type Error = <U as TryFrom<T>>::Error
🔬 This is a nightly-only experimental API. (
try_from)The type returned in the event of a conversion error.
fn try_into(self) -> Result<U, <U as TryFrom<T>>::Error> | [src] |
impl<T> Any for T where
T: 'static + ?Sized, [src]
impl<T> Any for T where
T: 'static + ?Sized, fn get_type_id(&self) -> TypeId | [src] |