Module init

Module init 

Types and functionalities to declare and initialize gdnative classes.

API endpoints

Three endpoints are automatically invoked by the engine during startup and shutdown:

All three must be present.

Registering a class using the godot_class macro

See the spinning_cube example in the repositiory.

Registering a class manually

See the manually_registered example in the repositiory.

Structs

ClassBuilder
ClassDescriptor
InitHandle
A handle that can register new classes to the engine during initialization.
Property
PropertyUsage
ScriptMethod
ScriptMethodAttributes
Signal
SignalArgument

Enums

PropertyHint
RpcMode

Traits

PropertyGetter
PropertySetter

Type Aliases

ScriptConstructorFn
ScriptDestructorFn
ScriptMethodFn