Dictionary

Struct Dictionary 

pub struct Dictionary(/* private fields */);
A reference-counted Dictionary of Variant key-value pairs.

Implementations

Source

impl Dictionary

pub fn new() -> Dictionary

Creates an empty Dictionary.

pub fn is_empty(&self) -> bool

Returns true if the Dictionary contains no elements.

pub fn len(&self) -> i32

Returns the number of elements in the Dictionary.

pub fn clear(&mut self)

Clears the Dictionary, removing all key-value pairs.

pub fn contains(&self, key: &Variant) -> bool

Returns true if the Dictionary contains the specified key.

pub fn contains_all(&self, keys: &VariantArray) -> bool

Returns true if the Dictionary has all of the keys in the given array.

pub fn erase(&mut self, key: &Variant)

Erase a key-value pair in the Dictionary by the specified key.

pub fn get(&self, key: &Variant) -> Variant

Returns a copy of the value corresponding to the key.

pub fn set(&mut self, key: &Variant, val: &Variant)

Sets a value to the element corresponding to the key.

pub fn get_ref(&self, key: &Variant) -> &Variant

Returns a reference to the value corresponding to the key.

pub fn get_mut_ref(&mut self, key: &Variant) -> &mut Variant

Returns a mutable reference to the value corresponding to the key.

pub fn to_json(&self) -> GodotString

Returns a GodotString of the Dictionary.

pub fn keys(&self) -> VariantArray

Returns an array of the keys in the Dictionary.

pub fn values(&self) -> VariantArray

Returns an array of the values in the Dictionary.

pub fn get_next(&self, key: &Variant) -> &Variant

pub fn hash(&self) -> i32

Return a hashed i32 value representing the dictionary’s contents.

pub fn new_ref(&self) -> Dictionary