pub struct Float32Array(/* private fields */);Expand description
A reference-counted vector of f32 that uses Godot’s pool allocator.
Implementations
Sourceimpl Float32Array
impl Float32Array
Sourcepub fn new() -> Float32Array
pub fn new() -> Float32Array
Creates an empty Float32Array.
Sourcepub fn from_variant_array(array: &VariantArray) -> Float32Array
pub fn from_variant_array(array: &VariantArray) -> Float32Array
Creates an array by trying to convert each variant.
See Variant::to_float32_array.
Sourcepub fn push_array(&mut self, array: &Float32Array)
pub fn push_array(&mut self, array: &Float32Array)
Appends a Float32Array at the end of this array.
Sourcepub fn insert(&mut self, offset: i32, val: f32) -> bool
pub fn insert(&mut self, offset: i32, val: f32) -> bool
Insert a new f32 at a given position in the array.
Sourcepub fn resize(&mut self, size: i32)
pub fn resize(&mut self, size: i32)
Changes the size of the array, possibly removing elements or pushing default values.
pub fn new_ref(&self) -> Float32Array