pub struct Int32Array(/* private fields */);Expand description
A reference-counted vector of i32 that uses Godot’s pool allocator.
Implementations
Sourceimpl Int32Array
impl Int32Array
Sourcepub fn new() -> Int32Array
pub fn new() -> Int32Array
Creates an empty Int32Array.
Sourcepub fn from_variant_array(array: &VariantArray) -> Int32Array
pub fn from_variant_array(array: &VariantArray) -> Int32Array
Creates an array by trying to convert each variant.
See Variant::to_int32_array.
Sourcepub fn push_array(&mut self, array: &Int32Array)
pub fn push_array(&mut self, array: &Int32Array)
Appends an Int32Array at the end of this array.
Sourcepub fn insert(&mut self, offset: i32, val: i32) -> bool
pub fn insert(&mut self, offset: i32, val: i32) -> bool
Insert a new int at a given position in the array.
Sourcepub fn resize(&mut self, size: i32)
pub fn resize(&mut self, size: i32)
Changes the size of the array, possibly removing elements or pushing default values.
pub fn new_ref(&self) -> Int32Array