pub struct Vector3Array(/* private fields */);Expand description
A reference-counted vector of Vector3 that uses Godot’s pool allocator.
Implementations
Sourceimpl Vector3Array
impl Vector3Array
Sourcepub fn new() -> Vector3Array
pub fn new() -> Vector3Array
Creates an empty array.
Sourcepub fn from_variant_array(array: &VariantArray) -> Vector3Array
pub fn from_variant_array(array: &VariantArray) -> Vector3Array
Creates an array by trying to convert each variant.
See Variant::to_vector3.
Sourcepub fn push(&mut self, vector: &TypedVector3D<f32, UnknownUnit>)
pub fn push(&mut self, vector: &TypedVector3D<f32, UnknownUnit>)
Appends a vector to the end of the array.
Sourcepub fn push_array(&mut self, vectors: &Vector3Array)
pub fn push_array(&mut self, vectors: &Vector3Array)
Appends each vector to the end of the array.
Sourcepub fn insert(
&mut self,
offset: i32,
vector: &TypedVector3D<f32, UnknownUnit>,
) -> bool
pub fn insert( &mut self, offset: i32, vector: &TypedVector3D<f32, UnknownUnit>, ) -> bool
Inserts a vector at the given offset.
Sourcepub fn resize(&mut self, size: i32)
pub fn resize(&mut self, size: i32)
Changes the size of the array, possibly removing elements or pushing default values.
Sourcepub fn get(&self, idx: i32) -> TypedVector3D<f32, UnknownUnit>
pub fn get(&self, idx: i32) -> TypedVector3D<f32, UnknownUnit>
Returns a copy of the element at the given offset.
Sourcepub fn set(&mut self, idx: i32, vector: &TypedVector3D<f32, UnknownUnit>)
pub fn set(&mut self, idx: i32, vector: &TypedVector3D<f32, UnknownUnit>)
Sets the value of the element at the given offset.
pub fn new_ref(&self) -> Vector3Array