#[repr(C)]
pub struct godot_gdnative_ext_arvr_api_struct {
pub type_: u32,
pub version: godot_gdnative_api_version,
pub next: *const godot_gdnative_api_struct,
pub godot_arvr_register_interface: Option<unsafe extern "C" fn(*const godot_arvr_interface_gdnative)>,
pub godot_arvr_get_worldscale: Option<unsafe extern "C" fn() -> f32>,
pub godot_arvr_get_reference_frame: Option<unsafe extern "C" fn() -> godot_transform>,
pub godot_arvr_blit: Option<unsafe extern "C" fn(i32, *mut godot_rid, *mut godot_rect2)>,
pub godot_arvr_get_texid: Option<unsafe extern "C" fn(*mut godot_rid) -> i32>,
pub godot_arvr_add_controller: Option<unsafe extern "C" fn(*mut i8, i32, bool, bool) -> i32>,
pub godot_arvr_remove_controller: Option<unsafe extern "C" fn(i32)>,
pub godot_arvr_set_controller_transform: Option<unsafe extern "C" fn(i32, *mut godot_transform, bool, bool)>,
pub godot_arvr_set_controller_button: Option<unsafe extern "C" fn(i32, i32, bool)>,
pub godot_arvr_set_controller_axis: Option<unsafe extern "C" fn(i32, i32, f32, bool)>,
pub godot_arvr_get_controller_rumble: Option<unsafe extern "C" fn(i32) -> f32>,
}
Formats the value using the given formatter. Read more
Performs copy-assignment from source. Read more
Returns the "default value" for a type. Read more
Creates owned data from borrowed data, usually by cloning. Read more
🔬 This is a nightly-only experimental API. (toowned_clone_into)
recently added
Uses borrowed data to replace owned data, usually by cloning. Read more
🔬 This is a nightly-only experimental API. (try_from)
The type returned in the event of a conversion error.
🔬 This is a nightly-only experimental API. (try_from)
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
🔬 This is a nightly-only experimental API. (try_from)
The type returned in the event of a conversion error.
🔬 This is a nightly-only experimental API. (try_from)
🔬 This is a nightly-only experimental API. (get_type_id)
this method will likely be replaced by an associated static